@@ -1,4 +1,4 @@
-// Copyright (c) 2020-2021 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2020-2022 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #ifndef TAO_PEGTL_CONTRIB_INTERNAL_SET_STACK_GUARD_HPP
@@ -12,7 +12,7 @@
 namespace TAO_PEGTL_NAMESPACE::internal
 {
    template< typename... Cs >
-   class set_stack_guard
+   class [[nodiscard]] set_stack_guard
    {
    public:
       template< typename... Ts >
@@ -24,8 +24,8 @@ namespace TAO_PEGTL_NAMESPACE::internal
       set_stack_guard( set_stack_guard&& ) = delete;
       set_stack_guard( const set_stack_guard& ) = delete;
 
-      void operator=( set_stack_guard&& ) = delete;
-      void operator=( const set_stack_guard& ) = delete;
+      set_stack_guard& operator=( set_stack_guard&& ) = delete;
+      set_stack_guard& operator=( const set_stack_guard& ) = delete;
 
       ~set_stack_guard()
       {
